@@ -1,3 +1,5 @@
+from django.utils import timezone
+from django.contrib.auth.models import User
 from rest_framework import authentication
 from rest_framework import exceptions
 
